#!/bin/ksh -p
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: das_monitor.ksh dasinstance [verbose]
#
# (%W%) %E%  %U%
#
# FUNCTION: Monitor method for DAS in TSA HA cluster
#
# Return 1 if DAS is online
# Return 2 otherwise
#
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

DASINSTANCE=${1}
VERBOSE=${2:-noverbose}

PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)

if [[ "$VERBOSE" == "verbose" ]]; then
   exec  2> /dev/null
else
   #  Close stdout   and   stderr
   exec  2> /dev/null
   exec  1> /dev/null
   set   +x
fi

if [[ -z $DASINSTANCE ]]; then
   logger -i -p err -t $0 "Error: Must specify instance name"
   echo 2
   return 2
fi

if [[ -z ${INSTHOME} ]] ; then
   userhome=~${DASINSTANCE?}
   eval userhome=$userhome
   INSTHOME=${userhome}
fi
if [[ -z ${INSTHOME} ]] ; then
   INSTHOME=$(cat /etc/passwd | grep "^${DASINSTANCE?}:" | cut -f 6 -d \:)
fi
if [[ -z ${INSTHOME} ]] ; then
   logger -i -p err -t $0 "Error: There is no home directory defined for ${DASINSTANCE?}"
   echo 2
   return 2
fi

INSTHOME=${INSTHOME#*=}
INSTHOME=${INSTHOME%%*( )}

# Check status...
p_pid=$(ps -fu ${DASINSTANCE} | grep -v grep | grep -c dasr)
if [[ $p_pid == 0 ]]; then
   rc=1
else
   rc=0
fi

# Above logic for rc is 0 if das is ok, non-zero otherwise
# Change logic to conform to cluster's expectations...
if [[ $rc == 0 ]]; then
   cluster_rc=1
else
   cluster_rc=2
fi

# logger -i -p info -t $0 "Returning $cluster_rc from $0 ($DASINSTANCE, $NN)"
echo $cluster_rc
return $cluster_rc
