#!/bin/ksh -p
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: das_start.ksh dasinstance [verbose]
#
# (%W%) %E%  %U%
#
# FUNCTION: Start method for DAS in TSA HA cluster
#
# PREREQS:  das_monitor.ksh
#
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

DASINSTANCE=${1}
VERBOSE=${2:-noverbose}

PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)

logger -i -p info -t $0 "Entering $0 ($DASINSTANCE)"

if [[ "$VERBOSE" == "verbose" ]]; then
   typeset -ft $(typeset +f)
   set -x
else
   # Close stdout and stderr
   exec 2> /dev/null
   exec 1> /dev/null
   set +x
fi

if [[ -z $DASINSTANCE ]]; then
   logger -i -p err -t $0 "Error: Must specify instance name"
   return 2
fi

if [[ -z ${INSTHOME} ]] ; then
   userhome=~${DASINSTANCE?}
   eval userhome=$userhome
   INSTHOME=${userhome}
fi
if [[ -z ${INSTHOME} ]] ; then
   INSTHOME=$(cat /etc/passwd | grep "^${DASINSTANCE?}:" | cut -f 6 -d \:)
fi
if [[ -z ${INSTHOME} ]] ; then
   logger -i -p err -t $0 "There is no home directory defined for ${DASINSTANCE?}"
   return 2
fi

INSTHOME=${INSTHOME#*=}
INSTHOME=${INSTHOME%%*( )}

###################################################################
# Start main...
su - ${DASINSTANCE?} -c "db2admin start"

$PROGPATH/das_monitor.ksh ${DASINSTANCE?}
rrc=$?
if [ $rrc -eq 2 ]; then
   rc=0
else
   rc=1
fi

logger -i -p info -t $0 "Returning $rc from $0 ($DASINSTANCE)"
return $rc
