#!/bin/ksh -p
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: db2_stop.ksh db2instance [verbose]
#
# (%W%) %E%  %U%
#
# FUNCTION: Stop method for DB2 in TSA HA cluster
#
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

export CT_MANAGEMENT_SCOPE=2

DB2INSTANCE=${1}
NN=${2:-0}
VERBOSE=${3:-noverbose}

PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)

logger -i -p info -t $PROGNAME "Entering $0"

if [[ "$VERBOSE" == "verbose" ]]; then
   typeset -ft $(typeset +f)
   set -x
else
   # Close stdout and stderr
   exec 2> /dev/null
   exec 1> /dev/null
   set +x
fi


###################################################################
# Start main error checking...
if [[ -z $DB2INSTANCE ]]; then
   logger -i -p err -t $PROGNAME "Error: Must specify instance name"
   return 0
fi

if [[ -z ${INSTHOME} ]] ; then
   userhome=~${DB2INSTANCE?}
   eval userhome=$userhome
   INSTHOME=${userhome}
fi
if [[ -z ${INSTHOME} ]] ; then
   INSTHOME=$(cat /etc/passwd | grep "^${DB2INSTANCE?}:" | cut -f 6 -d \:)
fi
if [[ -z ${INSTHOME} ]] ; then
   logger -i -p err -t $PROGNAME "Error: There is no home directory defined for ${DB2INSTANCE?}"
   return 0
fi

INSTHOME=${INSTHOME#*=}
INSTHOME=${INSTHOME%%*( )}
###################################################################
# main ...
logger -i -p notice -t $PROGNAME "Entered $0, $DB2INSTANCE, $NN"

# Do not need to stop if no process model
p_pid=$(ps -u ${DB2INSTANCE?} -o args | grep -c "^db2sysc ${NN?}[ ]*$")
if [[ $p_pid == 0 && $NN -eq 0 ]]; then
   p_pid=$(ps -u ${DB2INSTANCE?} -o args | grep -v "^db2sysc [0-9]" | grep -c "^db2sysc")
fi

if [[ $p_pid == 0 ]]; then
   logger -i -p notice -t $PROGNAME "Returning $rc from $0 ( $DB2INSTANCE, $NN ).  Partition already stopped."
   return 0
fi

# Ensure home directory is accessible ...
/bin/ksh -c "cd $INSTHOME/sqllib/bin" &
ProcNum=$!
sleep 2
kill -0 ${ProcNum} 2> /dev/null
ret=$?

if [[ $ret != 0 ]]; then
   logger -i -p notice -t $PROGNAME "Calling db2gcf -d -p $NN -i $DB2INSTANCE"
   $INSTHOME/sqllib/bin/db2gcf -t 130 -d -p ${NN?} -i ${DB2INSTANCE?}
   rc=$?
   logger -i -p notice -t $PROGNAME "db2gcf -d -p $NN -i $DB2INSTANCE returns : $rc"
else
   logger -i -p err -t $PROGNAME "Will do a hard kill of ( $DB2INSTANCE, $NN )"
   kill -9 $(ps -o pid,comm -u $DB2INSTANCE | grep "db2[a-z]" | awk '{print $1}') 2> /dev/null
   rc=3
   logger -i -p info -t $PROGNAME "Returning $rc from $0 ( $DB2INSTANCE, $NN )"
   return $rc
fi

if [ $rc -ne 0 ]; then
   logger -i -p notice -t $PROGNAME "Partition did not stop cleanly, must do a hard kill of ( $DB2INSTANCE, $NN )"
   logger -i -p notice -t $PROGNAME "Removing IPCs"
   su - ${DB2INSTANCE} -c "$INSTHOME/sqllib/bin/db2gcf -t 60 -k -p ${NN?} -i ${DB2INSTANCE?};ipclean -a"
   logger -i -p notice -t $PROGNAME "Killing db2 processes"
   kill -9 $(ps -o pid,comm -u $DB2INSTANCE | grep "db2[a-z]" | awk '{print $1}')
   rc=0
   logger -i -p notice -t $PROGNAME "Completed hard kill ( $DB2INSTANCE, $NN )"
fi

logger -i -p notice -t $PROGNAME "Returning $rc from $0 ( $DB2INSTANCE, $NN )"
return $rc
