#!/bin/ksh -p
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: hadr_stop.ksh
#
# (%W%) %E%  %U%
#
# FUNCTION: Stop HADR for specified HADR pair
#
# INPUT:  hadr_stop.ksh db2instp db2insts db2hadrdb verbose [S]
#
# OUTPUT: 0 if service stopped
#
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/sbin/rsct/bin
export PATH

logger -i  -p info -t $0 "$*"

RESOURCE_METHOD=stop

PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)
RT_BASEDIR=$PROGPATH
DB2HADRINSTANCE1=${1?}
DB2HADRINSTANCE2=${2?}
DB2HADRDBNAME=${3?}
VERBOSE=${4:-noverbose}
stop_standby_also=${5:-S}
VIRTUAL_STOP_ONLY="yes"
PROBE=
START=
STOP=$PROGNAME
SVC_PROBE=${RT_BASEDIR}/${PROBE:-hadr_monitor.ksh}
START_CMD=$RT_BASEDIR/${START:-hadr_start.ksh}
STOP_CMD=$RT_BASEDIR/${STOP:-hadr_stop.ksh}

export CT_MANAGEMENT_SCOPE=2

CLUSTER_APP_LABEL=db2hadr_${DB2HADRDBNAME?}

# Name the resource group and the resource
DATA_SVC_RG_NAME=${CLUSTER_APP_LABEL}-rg
DATA_SVC_R_NAME=${CLUSTER_APP_LABEL}-rs


if [[ "$VERBOSE" == "verbose" ]]; then
   typeset -ft $(typeset +f)
   set -x
else
   # Close stdout and stderr
   exec 2> /dev/null
   exec 1> /dev/null
   set +x
fi

##########################################################
# error_exit
##########################################################
error_exit()
{
   typeset exit_code="${rc:-1}"
   logger -i  -p err -t $0 " exiting with $exit_code"
   exit $exit_code
}


###########################################################
# resource_group_state_on_this_node()
#
# INPUT: ResourceClass, Resource, ResourceType, Node 
# OUTPUT:rg_state [Online=1 || Offline]
#
###########################################################
resource_group_state_on_this_node()
{
   OpState=$( lsrsrc-api -s ${ResourceClass}::'Name="'${Resource}'" '"${ResourceType}"' && NodeNameList={"'${Node}'"} '::OpState ) 

   rg_state=${OpState?}
}

###########################################################
# set_candidate_P_instance()
#
# INPUT: RSNAME1, RSNAME2, DB2HADRINSTANCE1, DB2HADRINTANCE2
# OUTPUT:candidate_P_instance
#
###########################################################
set_candidate_P_instance()
{
   Node=$(hostname | tr "." " " | awk '{print $1}')

   if   [[ $NodeRG1 == $Node && $NodeRG2 != $Node ]]; then
      candidate_P_instance=$DB2HADRINSTANCE1
      forceRGOffline=$RGNAME1
   elif [[ $NodeRG1 != $Node && $NodeRG2 == $Node ]]; then
      candidate_P_instance=$DB2HADRINSTANCE2
      forceRGOffline=$RGNAME2
   else
      # either both instances are up in resource groups
      # on this node, or neither is
      # figure out the one that wants to be primary
      HADR_LOCAL_HOST1=$(su - ${DB2HADRINSTANCE1?} -c "db2 get db cfg for ${DB2HADRDBNAME?}" | grep HADR_LOCAL_HOST | awk '{print $7}' | tr "." " " | awk '{print $1}' | tail -1)
      HADR_LOCAL_HOST2=$(su - ${DB2HADRINSTANCE2?} -c "db2 get db cfg for ${DB2HADRDBNAME?}" | grep HADR_LOCAL_HOST | awk '{print $7}' | tr "." " " | awk '{print $1}' | tail -1)
      if [[ $HADR_LOCAL_HOST1 == $Node ]]; then
         candidate_P_instance=$DB2HADRINSTANCE1
         forceRGOffline=$RGNAME1
      elif [[ $HADR_LOCAL_HOST2 == $Node ]]; then
         candidate_P_instance=$DB2HADRINSTANCE2
         forceRGOffline=$RGNAME2
      else
         candidate_P_instance=
         forceRGOfflineInCaseOfByForce=
      fi
   fi
}

###########################################################
# stophadr()
#
# Stop HADR on instance that is running local to this node
###########################################################
stophadr()
{
   set_candidate_P_instance
   instance_to_stop=$candidate_P_instance

   if [[ ! -z "$instance_to_stop" ]]; then
      chrg -o Offline ${forceRGOffline?}
      su - ${instance_to_stop?} -c "db2_kill"
   fi

   rc=0
   return $rc
}

#######################################################
# main()
#######################################################
main()
{
   touch /tmp/.virtual_offline_${CLUSTER_APP_LABEL?}
   rc=$?

   if [[ "$VIRTUAL_STOP_ONLY" != "yes" ]]; then
      stophadr  || error_exit $?
   fi
   logger -i -p info -t $0 "$CLUSTER_APP_LABEL returning $rc"
   return $rc
}
#
if  [[  "$VERBOSE" == "verbose"   ]]; then
   typeset -ft $(typeset   +f)
fi

main "${@:-}"

echo    $rc
exit    $rc
