#!/bin/ksh -p
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: mount_monitor.ksh mount_point [ verbose ]
#
# FUNCTION: Monitor method for filesystem in TSA cluster
#
# Return 1 if mount point is mounted and accessible (ie. online),
# Return 2 if mount point is not mounted
# Return 3 if mount point is mounted but IO errors
# Return 0 (Unknown) if bad input
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:$PATH

myname=$(basename $0)
dirname=$(dirname $0)

MP=${1}
VERBOSE=${2:-noverbose}

UNAME=$(uname)

#logger -i -p info -t $myname "Entering monitor for $MP"

if [[ "$VERBOSE" == "verbose" ]]; then
   exec   2> /dev/null
else
   #   Close stdout   and   stderr
   exec   2> /dev/null
   exec   1> /dev/null
   set +x
fi

if [[ -z $MP ]]; then
   logger -i -p err -t $0 "Error: Must specify mount point"
   logger -i -p err -t $myname "Returning $rc for mount $MP"
   rc=0
   echo $rc
   return $rc
fi

if [[ "${UNAME}" == "AIX" ]]; then
   #AIX
   blockDevice=$(cat /etc/filesystems | grep -p ${MP?}: | awk '{print $1 " " $2 " " $3}' | egrep "^dev = " | awk '{print $3}')

   if [[ -z $blockDevice ]]; then
      # This is not a valid mount point, it may be an RLV
      blockDevice=${MP?}
      unset MP
      rlv=true
   fi
   lvname=${blockDevice#/dev/}
   vgname=$(lslv $lvname 2> /dev/null | grep "VOLUME GROUP" | awk '{print $6}')
   majNum=$(ls -l /dev/$vgname | tr "," " " | awk '{print $5}')
   lspvLine=$(lspv -L | grep $vgname)
   diskID=$(echo $lspvLine | awk '{print $2}')
   hdiskID=$(echo $lspvLine | awk '{print $1}')
else
   blockDevice=$(cat /etc/fstab | awk '{print $1 " " $2}' | grep " ${MP}$" | awk '{print $1}')
fi

function isMounted
{
   let mounted=0
   if [[ "${UNAME}" == "AIX" ]]; then
      mounted=$(mount | awk '{print $2}' | grep -c "^${MP}\$")
   else
      mounted=$(mount | awk '{print $3}' | grep -c "^${MP}\$")
   fi
   if [[ -z $mounted ]]; then
      mounted=0
   fi
   return $mounted
}

###################################################################
# Start main...
let mounted=0
let rc=2
if [[ $rlv == "true" ]]; then
   # This will be case when MP passed in is acutally a RLV
   vgactive=$(echo $lspvLine | awk '{print $4}')
   if [[ "X$vgactive" == "Xactive" ]];then
      rc=1
      echo $rc
      return $rc
   else
      rc=2
      echo $rc
      return $rc
   fi
fi
isMounted
if [ ${mounted} -gt 0 ]; then
   touch ${MP}/.mp_monitor.$$
   if [ -f ${MP}/.mp_monitor.$$ ]; then
      rc=1
      rm -f ${MP}/.mp_monitor.$$
   else
      logger -i -p err -t $myname "Error performing I/O to file ${MP}/.mp_monitor.$$"
      $dirname/mount_stop.ksh $MP
      rc=3
   fi
fi

#logger -i -p info -t $myname "Returning $rc for mount $MP"
echo $rc
return $rc
