#!/bin/ksh
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: mount_start.ksh mount_point [ verbose ]
#
# FUNCTION: Start method for filesystem in TSA cluster
# Return 0 if mount point is mounted and accessible
# Return non-zero otherwise
#
# Notes: mount_stop.ksh may be called
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:$PATH

myname=$(basename $0)
dirname=$(dirname $0)
MP=${1}
VERBOSE=${2:-noverbose}

UNAME=$(uname)

logger -i -p info -t $myname "Entered ($MP)"

if [[ "$VERBOSE" == "verbose" ]]; then
   typeset -ft $(typeset +f)
   set -x
else
   # Close stdout and stderr
   exec 2> /dev/null
   exec 1> /dev/null
   set +x
fi

# Verify input...
if [[ -z $MP ]]; then
   logger -i -p err -t $myname "Error: Must specify mount point"
   rc=2
   logger -i -p err -t $myname "Returning $rc"
   return $rc
fi

if [[ $UNAME == "AIX" ]]; then
   #AIX

   blockDevice=$(cat /etc/filesystems | grep -p ${MP?}: | awk '{print $1 " " $2 " " $3}' | egrep "^dev = " | awk '{print $3}')

   if [[ -z $blockDevice ]]; then
      # This is not a valid mount point, it may be an RLV
      blockDevice=${MP?}
      unset MP
      rlv=true
   fi
   lvname=${blockDevice#/dev/}
   vgname=$(lslv $lvname 2> /dev/null | grep "VOLUME GROUP" | awk '{print $6}')
   majNum=$(ls -l /dev/$vgname | tr "," " " | awk '{print $5}')
   diskID=$(lspv | grep $vgname | awk '{print $2}')
   hdiskID=$(lspv | grep $vgname | awk '{print $1}')
   lvname=${blockDevice#/dev/}
   varyonvg ${vgname?}
else
   blockDevice=$(cat /etc/fstab | awk '{print $1 " " $2}' | grep " ${MP}$" | awk '{print $1}')
fi

function isMounted
{
   let mounted=0
   if [[ "${UNAME}" == "AIX" ]]; then
      mounted=$(mount | awk '{print $2}' | grep -c "^${MP}\$")
   else
      mounted=$(mount | awk '{print $3}' | grep -c "^${MP}\$")
   fi
   if [[ -z $mounted ]]; then
      mounted=0
   fi
   return $mounted
}

###################################################################
# Start main...
rc=0

# If already mounted correctly...
if [[ $rlv == "true" ]]; then
   # RLV
   return 0
fi

isMounted
if [ ${mounted} -gt 0 ]; then
   logger -i -p info -t $myname "$MP is already mounted"
   rm -f ${MP}/.mp_monitor 
   touch ${MP}/.mp_monitor 
   rc=$?
else
   # Ensure filesystem isn't mounted at all
   $dirname/mount_stop.ksh $MP
   rc=$?
   if [ $rc -gt 0 ]; then
      logger -i -p err -t $myname "$MP could not be cleanly umounted: $rc"
   else
      # Not mounted
      if [[ $UNAME == "AIX" ]]; then
         varyonvg ${vgname?}
      fi
      mount ${MP}
      rc=$?

      if [ $rc -eq 0 ]; then
         rm -f ${MP}/.mp_monitor 
         touch ${MP}/.mp_monitor
         rc=$?
         if [ $rc -ne 0 ]; then
            logger -i -p err -t $myname "$MP not writeable: $rc"
         fi
      fi
   fi
fi

logger -i -p info -t $myname "Returning $rc"
return $rc
