#!/bin/ksh -p
#-----------------------------------------------------------------------
# (C) COPYRIGHT International Business Machines Corp. 2001-2006
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME: mount_stop.ksh mount_point [verbose]
#
# FUNCTION: Stop method for filesystem in TSA cluster
#
# Return 0 if filesystem is unmounted cleanly
# Do not return until this occurs
#
#-----------------------------------------------------------------------
PATH=/bin:/usr/bin:/sbin:$PATH

myname=$(basename $0)
dirname=$(dirname $0)
MP=${1}
VERBOSE=${2:-noverbose}

UNAME=$(uname)

logger -i -p info -t $myname "Entered $MP"

if [[ "$VERBOSE" == "verbose" ]]; then
   typeset -ft $(typeset +f)
   set -x
else
   # Close stdout and stderr
   exec 2> /dev/null
   exec 1> /dev/null
   set +x
fi

if [[ -z $MP ]]; then
   logger -i -p err -t $myname "Error: Must specify mount point"
   return 2
fi

if [[ $UNAME == "AIX" ]]; then
   #AIX
   blockDevice=$(cat /etc/filesystems | grep -p ${MP?}: | awk '{print $1 " " $2 " " $3}' | egrep "^dev = " | awk '{print $3}')

   if [[ -z $blockDevice ]]; then
      # This is not a valid mount point, it may be an RLV
      blockDevice=${MP?}
      unset MP
      rlv=true
   fi
   lvname=${blockDevice#/dev/}
   vgname=$(lslv $lvname 2> /dev/null | grep "VOLUME GROUP" | awk '{print $6}')
   majNum=$(ls -l /dev/$vgname | tr "," " " | awk '{print $5}')
   diskID=$(lspv | grep $vgname | awk '{print $2}')
   hdiskID=$(lspv | grep $vgname | awk '{print $1}')
   lvname=${blockDevice#/dev/}
else
   blockDevice=$(cat /etc/fstab | awk '{print $1 " " $2}' | grep " ${MP}$" | awk '{print $1}')
fi


function isMounted
{
   let mounted=0
   if [[ "${UNAME}" == "AIX" ]]; then
      mounted=$(mount | awk '{print $2}' | grep -c "^${MP}\$")
   else
      mounted=$(mount | awk '{print $3}' | grep -c "^${MP}\$")
   fi
   if [[ -z $mounted ]]; then
      mounted=0
   fi
   return $mounted
}

###################################################################
# Start main...
rc=0

if [[ $rlv == "true" ]]; then
   # RLV
   varyoffvg ${vgname?}
fi

isMounted
if [[ $mounted == 0 ]]; then
   logger -i -p info -t $myname "Filesystem ${MP} isn't mounted on this node" 
else
   # Clean up dir and umount it
   rm -f ${MP}/.mp_monitor
   umount $MP
   if [[ $UNAME == "AIX" ]]; then
      varyoffvg ${vgname?}
   fi
   isMounted
   while [ $mounted != 0 ];
   do
      if [[ "${UNAME}" == "AIX" ]]; then
         exportfs -u ${MP}
         list_of_pids_to_be_killed=$(fuser -c $MP)
      else
         exportfs -u :${MP}
         list_of_pids_to_be_killed=$(fuser -m $MP)
      fi
      if [[ ! -z $list_of_pids_to_be_killed ]]; then
         logger -i -p notice -t $myname "Killing following list of pids: $list_of_pids_to_be_killed" 
         if [[ "${UNAME}" == "AIX" ]]; then
            fuser -kxuc $MP 
         else
            fuser -mk $MP 
         fi
      fi
      umount $MP
      if [[ $UNAME == "AIX" ]]; then
         varyoffvg ${vgname?}
      fi

      sleep 1
      isMounted
   done
fi

logger -i -p info -t $myname "Returning $mounted for $MP"
return $mounted
